@@ -1,6 +1,6 @@
 /*
   PLAYWAVE:  A test application for the SDL mixer library.
-  Copyright (C) 1997-2018 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2024 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -19,7 +19,7 @@
   3. This notice may not be removed or altered from any source distribution.
 */
 
-/* $Id$ */
+#include "SDL_stdinc.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -118,15 +118,15 @@ static void output_versions(const char *libname, const SDL_version *compiled,
 static void test_versions(void)
 {
     SDL_version compiled;
-    const SDL_version *linked;
+    SDL_version linked;
 
     SDL_VERSION(&compiled);
-    linked = SDL_Linked_Version();
-    output_versions("SDL", &compiled, linked);
+    SDL_GetVersion(&linked);
+    output_versions("SDL", &compiled, &linked);
 
     SDL_MIXER_VERSION(&compiled);
-    linked = Mix_Linked_Version();
-    output_versions("SDL_mixer", &compiled, linked);
+    SDL_memcpy(&linked, Mix_Linked_Version(), sizeof(SDL_version));
+    output_versions("SDL_mixer", &compiled, &linked);
 }
 #endif
 
@@ -137,7 +137,7 @@ static void SDLCALL channel_complete_callback (int chan)
 {
     Mix_Chunk *done_chunk = Mix_GetChunk(chan);
     SDL_Log("We were just alerted that Mixer channel #%d is done.\n", chan);
-    SDL_Log("Channel's chunk pointer is (%p).\n", done_chunk);
+    SDL_Log("Channel's chunk pointer is (%p).\n", (void*)done_chunk);
     SDL_Log(" Which %s correct.\n", (wave == done_chunk) ? "is" : "is NOT");
     channel_is_done = 1;
 }
@@ -148,9 +148,9 @@ static void SDLCALL channel_complete_callback (int chan)
 static int still_playing(void)
 {
 #ifdef TEST_MIX_CHANNELFINISHED
-    return(!channel_is_done);
+    return !channel_is_done;
 #else
-    return(Mix_Playing(0));
+    return Mix_Playing(0);
 #endif
 }
 
@@ -160,12 +160,12 @@ static void do_panning_update(void)
 {
     static Uint8 leftvol = 128;
     static Uint8 rightvol = 128;
-    static Uint8 leftincr = -1;
-    static Uint8 rightincr = 1;
+    static Sint8 leftincr = -1;
+    static Sint8 rightincr = 1;
     static int panningok = 1;
     static Uint32 next_panning_update = 0;
 
-    if ((panningok) && (SDL_GetTicks() >= next_panning_update)) {
+    if (panningok && (SDL_GetTicks() >= next_panning_update)) {
         panningok = Mix_SetPanning(0, leftvol, rightvol);
         if (!panningok) {
             SDL_Log("Mix_SetPanning(0, %d, %d) failed!\n",
@@ -174,14 +174,16 @@ static void do_panning_update(void)
         }
 
         if ((leftvol == 255) || (leftvol == 0)) {
-            if (leftvol == 255)
+            if (leftvol == 255) {
                 SDL_Log("All the way in the left speaker.\n");
-                leftincr *= -1;
+            }
+            leftincr *= -1;
         }
 
         if ((rightvol == 255) || (rightvol == 0)) {
-            if (rightvol == 255)
+            if (rightvol == 255) {
                 SDL_Log("All the way in the right speaker.\n");
+            }
             rightincr *= -1;
         }
 
@@ -197,7 +199,7 @@ static void do_panning_update(void)
 static void do_distance_update(void)
 {
     static Uint8 distance = 1;
-    static Uint8 distincr = 1;
+    static Sint8 distincr = 1;
     static int distanceok = 1;
     static Uint32 next_distance_update = 0;
 
@@ -229,13 +231,13 @@ static void do_position_update(void)
 {
     static Sint16 distance = 1;
     static Sint8 distincr = 1;
-    static Uint16 angle = 0;
+    static Sint16 angle = 0;
     static Sint8 angleincr = 1;
     static int positionok = 1;
     static Uint32 next_position_update = 0;
 
-    if ((positionok) && (SDL_GetTicks() >= next_position_update)) {
-        positionok = Mix_SetPosition(0, angle, distance);
+    if (positionok && (SDL_GetTicks() >= next_position_update)) {
+        positionok = Mix_SetPosition(0, angle, (Uint8)distance);
         if (!positionok) {
             SDL_Log("Mix_SetPosition(0, %d, %d) failed!\n",
                     (int) angle, (int) distance);
@@ -253,7 +255,6 @@ static void do_position_update(void)
         }
 
         distance += distincr;
-
         if (distance < 0) {
             distance = 0;
             distincr = 3;
@@ -365,6 +366,8 @@ int main(int argc, char *argv[])
     int reverse_stereo = 0;
     int reverse_sample = 0;
 
+    (void) argc;
+
 #ifdef HAVE_SETBUF
     setbuf(stdout, NULL);    /* rcg06132001 for debugging purposes. */
     setbuf(stderr, NULL);    /* rcg06192001 for debugging purposes, too. */
@@ -374,10 +377,10 @@ int main(int argc, char *argv[])
     /* Initialize variables */
     audio_rate = MIX_DEFAULT_FREQUENCY;
     audio_format = MIX_DEFAULT_FORMAT;
-    audio_channels = 2;
+    audio_channels = MIX_DEFAULT_CHANNELS;
 
     /* Check command line usage */
-    for (i=1; argv[i] && (*argv[i] == '-'); ++i) {
+    for (i = 1; argv[i] && (*argv[i] == '-'); ++i) {
         if ((strcmp(argv[i], "-r") == 0) && argv[i+1]) {
             ++i;
             audio_rate = atoi(argv[i]);
@@ -405,18 +408,18 @@ int main(int argc, char *argv[])
             reverse_sample = 1;
         } else {
             Usage(argv[0]);
-            return(1);
+            return 1;
         }
     }
-    if (! argv[i]) {
+    if (!argv[i]) {
         Usage(argv[0]);
-        return(1);
+        return 1;
     }
 
     /* Initialize the SDL library */
     if (SDL_Init(SDL_INIT_AUDIO) < 0) {
         SDL_Log("Couldn't initialize SDL: %s\n",SDL_GetError());
-        return(255);
+        return 255;
     }
 #ifdef HAVE_SIGNAL_H
     signal(SIGINT, CleanUp);
@@ -453,8 +456,7 @@ int main(int argc, char *argv[])
     /* Load the requested wave file */
     wave = Mix_LoadWAV(argv[i]);
     if (wave == NULL) {
-        SDL_Log("Couldn't load %s: %s\n",
-                        argv[i], SDL_GetError());
+        SDL_Log("Couldn't load %s: %s\n", argv[i], SDL_GetError());
         CleanUp(2);
     }
 
